==> kimageannotator_0.5.3.orig.tar.gz: kImageAnnotator-0.5.3/translations/kImageAnnotator_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Aranjează</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Adu în față</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Adu mai în față</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Trimite mai în spate</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Trimite în spate</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Alege acesta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiază</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lipește</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifică</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Configurări generale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Configurări imagine</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Culoare</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Culoare text</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Lățime</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Sămânță numerică</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Factor de eclipsare</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Umbră element</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Configurări element</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Închide celelalte</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Închide toate</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Închide toate la stânga</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Închide toate la dreapta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Alegere unealtă</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Activat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dezactivat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Î:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Vizibilitate contur și umplere</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Contur și umplere</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Contur fără umplere</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Fără contur și fără umplere</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Dimensiune font</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Aldin</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subliniat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efecte imagine</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Fără efect</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Lasă umbră</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Nuanțe de gri</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Contur</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inversează culoarea</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restricționat</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>La activare forțează canavaua
să includă imaginea de fundal.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Î:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Culoare:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Culoare fundal canava</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotește imaginea</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° în sens contrar acelor de ceasornic</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrar</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Valorile pozitive rotesc în sensul acelor de ceasornic, cele negative – în sens contrar.
Rotirea cu non-multiplu de 90° poate introduce pierderi de calitate.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotește</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Răstoarnă</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Scalează imaginea</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Păstrează raportul de aspect</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lățime:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Înălțime:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Autocolant</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Alege</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stilou</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Număr</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Dreptunghi marcator</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elipsă marcatoare</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Stilou marcator</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Săgeată</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Săgeată dublă</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Estompare</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dreptunghi</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsă</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Indicator numeric</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Autocolant</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelează</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Indicator textual</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Săgeată textuală</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Săgeată numerică</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplică</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Apropie (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Îndepărtează (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reinițializează apropierea (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.1.orig.tar.gz: kImageAnnotator-0.7.1/translations/kImageAnnotator_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Aranjează</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Adu în față</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Adu mai în față</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Trimite mai în spate</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Trimite în spate</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Alege acesta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiază</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lipește</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifică</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Configurări generale</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Configurări imagine</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Culoare</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Culoare text</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Lățime</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Sămânță numerică</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Factor de eclipsare</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Umbră element</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Configurări element</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Închide celelalte</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Închide toate</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Închide toate la stânga</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Închide toate la dreapta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Alegere unealtă</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Activat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dezactivat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Rotește</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Î:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Vertical</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Orizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Aplică</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Renunță</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Vizibilitate contur și umplere</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Contur și umplere</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Contur fără umplere</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Fără contur și fără umplere</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Dimensiune font</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Aldin</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subliniat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efecte imagine</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Fără efect</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Lasă umbră</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Nuanțe de gri</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Contur</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inversează culoarea</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restricționat</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>La activare forțează canavaua
să includă imaginea de fundal.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Î:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Culoare:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Culoare fundal canava</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotește imaginea</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° în sensul acelor de ceasornic</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° în sens contrar acelor de ceasornic</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrar</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Valorile pozitive rotesc în sensul acelor de ceasornic, cele negative – în sens contrar.
Rotirea cu non-multiplu de 90° poate introduce pierderi de calitate.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotește</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Răstoarnă</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Scalează imaginea</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Păstrează raportul de aspect</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lățime:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Înălțime:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Autocolant</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Alege</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stilou</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Număr</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Dreptunghi marcator</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elipsă marcatoare</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Stilou marcator</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Săgeată</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Săgeată dublă</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Estompare</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dreptunghi</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsă</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Indicator numeric</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Autocolant</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelează</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Indicator textual</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Săgeată textuală</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Săgeată numerică</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplică</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Apropie (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Îndepărtează (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reinițializează apropierea (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
